@@ -4,7 +4,8 @@ from .utils.generic import setimuattr
 from .utils.string import normstr
 
 from io import IOBase
-from typing import Callable, Iterable, Optional
+from types import BuiltinMethodType
+from typing import Iterable, Optional
 
 @immutable
 class PysBuffer(Pys):
@@ -14,15 +15,14 @@ class PysFileBuffer(PysBuffer):
 
     __slots__ = ('text', 'name')
 
-    def __init__(
-        self,
-        text: str | bytes | bytearray | Iterable | Callable | IOBase | 'PysFileBuffer',
+    def __new__(
+        cls,
+        text: str | bytes | bytearray | Iterable | BuiltinMethodType | IOBase | 'PysFileBuffer',
         name: Optional[str | bytes] = None
-    ) -> None:
+    ) -> 'PysFileBuffer':
 
         if isinstance(text, PysFileBuffer):
-            name = normstr(text.name if name is None else name)
-            text = normstr(text.text)
+            return text
 
         elif isinstance(text, IOBase):
             name = normstr(getattr(text, 'name', '<io>') if name is None else name)
@@ -32,8 +32,12 @@ class PysFileBuffer(PysBuffer):
             name = '<string>' if name is None else normstr(name)
             text = normstr(text)
 
-        setimuattr(self, 'text', text)
-        setimuattr(self, 'name', name)
+        instance = super().__new__(cls)
+
+        setimuattr(instance, 'text', text)
+        setimuattr(instance, 'name', name)
+
+        return instance
 
     def __repr__(self) -> str:
         return f'<FileBuffer from {self.name!r}>'
\ No newline at end of file
