@@ -3,6 +3,7 @@ from . import (
     debug,
     decorators,
     generic,
+    jsdict,
     module,
     path,
     shell,
@@ -15,6 +16,7 @@ __all__ = (
     'debug',
     'decorators',
     'generic',
+    'jsdict',
     'module',
     'path',
     'shell',
